<?php defined('SYSPATH') or die('No direct script access.');

class Payments
{	
	/**
	 * Klasa do obsługi płatoności
	 * @private object
	 */
	private $api_class = null; 
	
	/**
	 * Lokalizacja płatności
	 * @public string
	 */
	public $payments_dir = null;
	
	/**
	 * Konstruktor
	 *
	 *
	 */
	public function __construct()
	{	
		// Zapiszmy lokalizacja płatności
		$this->payments_dir = 'modules/Payments/';
		
		// Pobierzmy obiekt ustawień
		$settings = Core::get('Settings');
		
		// Pobierzmy nazwę aktualnie używanego API
		$api = $settings->get('sms_api_name');
		
		// Jeśli takie API nie istnieje, ustawmy na API domyślne
		if(!is_readable( $this->payments_dir . $api . '.php'))
		{
			$api = 'Pukawka';
			$settings->update('sms_api_name', 'Pukawka');
		}
		
		// Wygenerujmy ścieżkę do pliku i go dołączmy
		$dir = $this->payments_dir . $api . '.php';
		require_once($dir);
		
		// Wygenerujmy nazwe klasy i utwórzmy jej obiekt...
		$class = 'Payments_' . $api;
		$this->api_class = new $class();
	}
	
	/**
	 * Zwraca listę płatności.
	 *
	 * @access public
	 * @return array
	 */
	public function getPayments()
	{
		$paymentsList = array();
		
		$dir = opendir($this->payments_dir);
		while($f = readdir($dir))
		{
			if($f=='.' or $f=='..' or is_dir($this->payments_dir . $f))
			{
				continue;
			}
		
			$info = pathinfo($f);
			
			$paymentsList[] = $info['filename'];
		}
		
		return $paymentsList;
	}
	
	
	/**
	 * Sprawdza poprawność sms'a i zwraca kwote doładowania.
	 *
	 *
	 * @param $sms   string kod zwrotny który otrzymał użytkownik
	 * @param $numer string numer sms
	 * @param $code  string treść smsa jaką wysłał użytkownik
	 *
	 * @return array
	 */
	public function check($sms, $numer, $code)
	{
		$premium_code = Code::get($sms);
		if(count($premium_code))
		{
			if(isset($premium_code['id']) && !$premium_code['active_member_id'])
			{
				Code::setStatus(Member::logged(), $premium_code['id']);
				return array(
					(float)$premium_code['wallet'],
					'Doładowałeś konto kodem promocyjnym o wartości <b>' . $premium_code['wallet'] . '</b> PLN'
				);
			}
		}
		return $this->api_class->check($sms, $numer, $code);
	}
	
	
	/**
	 * Zwraca stawki sms
	 *
	 * 
	 * @access public
	 * @return array  stawki sms
	 */
	public function rates()
	{
		return $this->api_class->rates();
	}
	
	/**
	 * Metoda magiczna __call
	 *
	 * @param $method string nazwa metody
	 *
	 * @return void
	 */
	public function __call($method, $args)
	{
		if(method_exists($this->api_class, $method))
		{
			return $this->api_class->{$method}($args);
		}
		return false;
	}
}