<?php defined('SYSPATH') or die('No direct script access.');

class Settings
{
	/**
	 * Ustawienia
	 * @public array
	 */
	public $settings = array();
	
	/**
	 * Replace value...
	 * @private array
	 */
	private $_replace = array();
	
	/**
	 * Pobiera dane z mysql
	 *
	 */
	public function __construct()
	{
		$this->_replace = array(
			'{SITE_URL}' => Core::$site
		);
		$this->settings = $this->getSettings();
	}
	
	/**
	 * Pobiera i zwraca ustawienia skryptu z mysql
	 *
	 * @access public
	 * @return array
	 */
	public function getSettings()
	{
		foreach(Core::db()->query('SELECT * FROM `settings_`') as $data)
		{
			$setting[$data['setting_name']] = array(
				$this->_format($data['setting_value'], $this->_replace),
				$data['setting_desc'], // opis
				$data['setting_value'] // nie sformatowana wartość
			);
		}
		return $setting;
	}
	
	/**
	 * Zwraca ustawienie...
	 *
	 *
	 * @param string
	 * @param string
	 * @return string
	 */
	public function get($setting_name, $default = FALSE, $format = array())
	{
		// Pobieranie wartości
		$value = isset($this->settings[$setting_name]) ? $this->settings[$setting_name][0] : $default;
		
		// Formatowanie
		return $this->_format($value, $format);
	}
	
	/**
	 * Zwraca Opis ustawienia
	 *
	 *
	 * @param string
	 * @param string
	 * @return string
	 */
	public function getDesc($setting_name, $default = FALSE)
	{
		return isset($this->settings[$setting_name]) ? $this->settings[$setting_name][1] : $default;
	}
	
	/**
	 * Zwraca Wartość ustawień bez formatowania
	 *
	 *
	 * @param string
	 * @param string
	 * @return string
	 */
	public function getNoFormat($setting_name, $default = FALSE)
	{
		return isset($this->settings[$setting_name]) ? $this->settings[$setting_name][2] : $default;
	}
	
	
	/**
	 * Update...
	 *
	 * @param string
	 * @param string
	 * @return int
 	 */
	public function update($setting_name, $setting_value)
	{
		if(!isset($this->settings[$setting_name]))
		{
			return $this->create($setting_name, $setting_value);
		}
	
		$query = Core::db()->prepare('UPDATE `settings_` SET `setting_value` = ? where `setting_name` = ?');
		$query->execute(array($setting_value, $setting_name));
		
		return $query->rowCount();
	}
	
	/**
	 * Dodaje nowe ustawienie
	 *
	 * @param string
	 * @param string
	 * @param string
	 * @return int
	 */
	public function create($setting_name, $setting_value = '', $setting_desc = '')
	{
		if($setting_name == '')
		{
			return 0;
		}
	
		$insert = Core::db()->prepare('INSERT INTO `settings_` VALUES(?, ?, ?)');
		$insert->execute(array($setting_name, $setting_value, $setting_desc));
		
		return $insert->rowCount();
	}
	
	
	/**
	 * Formatuje ciąg znaków
	 *
	 * @param string
	 * @param array
	 *
	 * @access public
	 * @return string
	 */
	public function _format($string, array $format)
	{
		return str_replace(array_keys($format), array_values($format), $string);
	}
}